==> drei-10.1.2.tgz: package/native/index.js <==
export { Billboard } from '../core/Billboard.js';
export { ScreenSpace } from '../core/ScreenSpace.js';
export { ScreenSizer } from '../core/ScreenSizer.js';
export { QuadraticBezierLine } from '../core/QuadraticBezierLine.js';
export { CubicBezierLine } from '../core/CubicBezierLine.js';
export { CatmullRomLine } from '../core/CatmullRomLine.js';
export { Line } from '../core/Line.js';
export { PositionalAudio } from '../core/PositionalAudio.js';
export { Text } from '../core/Text.js';
export { Text3D } from '../core/Text3D.js';
export { Effects, isWebGL2Available } from '../core/Effects.js';
export { GradientTexture, GradientType } from '../core/GradientTexture.js';
export { Image } from '../core/Image.js';
export { Edges } from '../core/Edges.js';
export { Outlines } from '../core/Outlines.js';
export { Trail, useTrail } from '../core/Trail.js';
export { Sampler, useSurfaceSampler } from '../core/Sampler.js';
export { ComputedAttribute } from '../core/ComputedAttribute.js';
export { Clone } from '../core/Clone.js';
export { MarchingCube, MarchingCubes, MarchingPlane } from '../core/MarchingCubes.js';
export { Decal } from '../core/Decal.js';
export { Svg } from '../core/Svg.js';
export { Gltf, useGLTF } from '../core/Gltf.js';
export { AsciiRenderer } from '../core/AsciiRenderer.js';
export { Splat } from '../core/Splat.js';
export { OrthographicCamera } from '../core/OrthographicCamera.js';
export { PerspectiveCamera } from '../core/PerspectiveCamera.js';
export { CubeCamera, useCubeCamera } from '../core/CubeCamera.js';
export { DeviceOrientationControls } from '../core/DeviceOrientationControls.js';
export { FlyControls } from '../core/FlyControls.js';
export { MapControls } from '../core/MapControls.js';
export { OrbitControls } from '../core/OrbitControls.js';
export { TrackballControls } from '../core/TrackballControls.js';
export { ArcballControls } from '../core/ArcballControls.js';
export { TransformControls } from '../core/TransformControls.js';
export { PointerLockControls } from '../core/PointerLockControls.js';
export { FirstPersonControls } from '../core/FirstPersonControls.js';
export { CameraControls } from '../core/CameraControls.js';
export { default as CameraControlsImpl } from 'camera-controls';
export { MotionPathControls, useMotion } from '../core/MotionPathControls.js';
export { GizmoHelper, useGizmoContext } from '../core/GizmoHelper.js';
export { GizmoViewcube } from '../core/GizmoViewcube.js';
export { GizmoViewport } from '../core/GizmoViewport.js';
export { Grid } from '../core/Grid.js';
export { CubeTexture, useCubeTexture } from '../core/CubeTexture.js';
export { Fbx, useFBX } from '../core/Fbx.js';
export { Ktx2, useKTX2 } from '../core/Ktx2.js';
export { Progress, useProgress } from '../core/Progress.js';
export { IsObject, Texture, useTexture } from '../core/Texture.js';
export { VideoTexture, useVideoTexture } from '../core/VideoTexture.js';
export { useFont } from '../core/useFont.js';
export { checkIfFrameIsEmpty, getFirstFrame, useSpriteLoader } from '../core/useSpriteLoader.js';
export { Helper, useHelper } from '../core/Helper.js';
export { Stats } from '../core/Stats.js';
export { StatsGl } from '../core/StatsGl.js';
export { useDepthBuffer } from '../core/useDepthBuffer.js';
export { useAspect } from '../core/useAspect.js';
export { useCamera } from '../core/useCamera.js';
export { DetectGPU, useDetectGPU } from '../core/DetectGPU.js';
export { Bvh, useBVH } from '../core/Bvh.js';
export { useContextBridge } from '../core/useContextBridge.js';
export { useAnimations } from '../core/useAnimations.js';
export { Fbo, useFBO } from '../core/Fbo.js';
export { useIntersect } from '../core/useIntersect.js';
export { useBoxProjectedEnv } from '../core/useBoxProjectedEnv.js';
export { BBAnchor } from '../core/BBAnchor.js';
export { TrailTexture, useTrailTexture } from '../core/TrailTexture.js';
export { Example } from '../core/Example.js';
export { SpriteAnimator, useSpriteAnimator } from '../core/SpriteAnimator.js';
export { CurveModifier } from '../core/CurveModifier.js';
export { MeshDistortMaterial } from '../core/MeshDistortMaterial.js';
export { MeshWobbleMaterial } from '../core/MeshWobbleMaterial.js';
export { MeshReflectorMaterial } from '../core/MeshReflectorMaterial.js';
export { MeshRefractionMaterial } from '../core/MeshRefractionMaterial.js';
export { MeshTransmissionMaterial } from '../core/MeshTransmissionMaterial.js';
export { MeshDiscardMaterial } from '../core/MeshDiscardMaterial.js';
export { MultiMaterial } from '../core/MultiMaterial.js';
export { PointMaterial, PointMaterialImpl } from '../core/PointMaterial.js';
export { shaderMaterial } from '../core/shaderMaterial.js';
export { SoftShadows } from '../core/softShadows.js';
export { Box, Capsule, Circle, Cone, Cylinder, Dodecahedron, Extrude, Icosahedron, Lathe, Octahedron, Plane, Polyhedron, Ring, Shape, Sphere, Tetrahedron, Torus, TorusKnot, Tube } from '../core/shapes.js';
export { RoundedBox } from '../core/RoundedBox.js';
export { ScreenQuad } from '../core/ScreenQuad.js';
export { Center } from '../core/Center.js';
export { Resize } from '../core/Resize.js';
export { Bounds, useBounds } from '../core/Bounds.js';
export { CameraShake } from '../core/CameraShake.js';
export { Float } from '../core/Float.js';
export { Stage } from '../core/Stage.js';
export { Backdrop } from '../core/Backdrop.js';
export { Shadow } from '../core/Shadow.js';
export { Caustics } from '../core/Caustics.js';
export { ContactShadows } from '../core/ContactShadows.js';
export { AccumulativeShadows, RandomizedLight, accumulativeContext } from '../core/AccumulativeShadows.js';
export { SpotLight, SpotLightShadow } from '../core/SpotLight.js';
export { Environment, EnvironmentCube, EnvironmentMap, EnvironmentPortal } from '../core/Environment.js';
export { Lightformer } from '../core/Lightformer.js';
export { Sky, calcPosFromAngles } from '../core/Sky.js';
export { Stars } from '../core/Stars.js';
export { Cloud, CloudInstance, Clouds } from '../core/Cloud.js';
export { Sparkles } from '../core/Sparkles.js';
export { useEnvironment } from '../core/useEnvironment.js';
export { MatcapTexture, useMatcapTexture } from '../core/MatcapTexture.js';
export { NormalTexture, useNormalTexture } from '../core/NormalTexture.js';
export { Wireframe } from '../core/Wireframe.js';
export { ShadowAlpha } from '../core/ShadowAlpha.js';
export { Point, Points, PointsBuffer, PositionPoint } from '../core/Points.js';
export { Instance, InstancedAttribute, Instances, Merged, PositionMesh, createInstances } from '../core/Instances.js';
export { Segment, SegmentObject, Segments } from '../core/Segments.js';
export { Detailed } from '../core/Detailed.js';
export { Preload } from '../core/Preload.js';
export { BakeShadows } from '../core/BakeShadows.js';
export { meshBounds } from '../core/meshBounds.js';
export { AdaptiveDpr } from '../core/AdaptiveDpr.js';
export { AdaptiveEvents } from '../core/AdaptiveEvents.js';
export { PerformanceMonitor, usePerformanceMonitor } from '../core/PerformanceMonitor.js';
export { RenderTexture } from '../core/RenderTexture.js';
export { RenderCubeTexture } from '../core/RenderCubeTexture.js';
export { Mask, useMask } from '../core/Mask.js';
export { Hud } from '../core/Hud.js';
export { Fisheye } from '../core/Fisheye.js';
export { MeshPortalMaterial } from '../core/MeshPortalMaterial.js';
export { calculateScaleFactor } from '../core/calculateScaleFactor.js';
import '@babel/runtime/helpers/esm/extends';
import 'react';
import 'three';
import '@react-three/fiber';
import 'three-stdlib';
import 'troika-three-text';
import 'suspend-react';
import '../helpers/constants.js';
import 'meshline';
import 'maath';
import 'zustand';
import 'hls.js';
import 'stats.js';
import '../helpers/useEffectfulState.js';
import 'stats-gl';
import 'detect-gpu';
import 'three-mesh-bvh';
import '../helpers/deprecated.js';
import '../materials/BlurPass.js';
import '../materials/ConvolutionMaterial.js';
import '../materials/MeshReflectorMaterial.js';
import '../materials/MeshRefractionMaterial.js';
import '../materials/DiscardMaterial.js';
import '@monogrid/gainmap-js';
import '../helpers/environment-assets.js';
import '../materials/SpotLightMaterial.js';
import '../materials/WireframeMaterial.js';

==> drei-10.2.0.tgz: package/native/index.js <==
export { Billboard } from '../core/Billboard.js';
export { ScreenSpace } from '../core/ScreenSpace.js';
export { ScreenSizer } from '../core/ScreenSizer.js';
export { QuadraticBezierLine } from '../core/QuadraticBezierLine.js';
export { CubicBezierLine } from '../core/CubicBezierLine.js';
export { CatmullRomLine } from '../core/CatmullRomLine.js';
export { Line } from '../core/Line.js';
export { PositionalAudio } from '../core/PositionalAudio.js';
export { Text } from '../core/Text.js';
export { Text3D } from '../core/Text3D.js';
export { Effects, isWebGL2Available } from '../core/Effects.js';
export { GradientTexture, GradientType } from '../core/GradientTexture.js';
export { Image } from '../core/Image.js';
export { Edges } from '../core/Edges.js';
export { Outlines } from '../core/Outlines.js';
export { Trail, useTrail } from '../core/Trail.js';
export { Sampler, useSurfaceSampler } from '../core/Sampler.js';
export { ComputedAttribute } from '../core/ComputedAttribute.js';
export { Clone } from '../core/Clone.js';
export { MarchingCube, MarchingCubes, MarchingPlane } from '../core/MarchingCubes.js';
export { Decal } from '../core/Decal.js';
export { Svg } from '../core/Svg.js';
export { Gltf, useGLTF } from '../core/Gltf.js';
export { AsciiRenderer } from '../core/AsciiRenderer.js';
export { Splat } from '../core/Splat.js';
export { OrthographicCamera } from '../core/OrthographicCamera.js';
export { PerspectiveCamera } from '../core/PerspectiveCamera.js';
export { CubeCamera, useCubeCamera } from '../core/CubeCamera.js';
export { DeviceOrientationControls } from '../core/DeviceOrientationControls.js';
export { FlyControls } from '../core/FlyControls.js';
export { MapControls } from '../core/MapControls.js';
export { OrbitControls } from '../core/OrbitControls.js';
export { TrackballControls } from '../core/TrackballControls.js';
export { ArcballControls } from '../core/ArcballControls.js';
export { TransformControls } from '../core/TransformControls.js';
export { PointerLockControls } from '../core/PointerLockControls.js';
export { FirstPersonControls } from '../core/FirstPersonControls.js';
export { CameraControls } from '../core/CameraControls.js';
export { default as CameraControlsImpl } from 'camera-controls';
export { MotionPathControls, useMotion } from '../core/MotionPathControls.js';
export { GizmoHelper, useGizmoContext } from '../core/GizmoHelper.js';
export { GizmoViewcube } from '../core/GizmoViewcube.js';
export { GizmoViewport } from '../core/GizmoViewport.js';
export { Grid } from '../core/Grid.js';
export { CubeTexture, useCubeTexture } from '../core/CubeTexture.js';
export { Fbx, useFBX } from '../core/Fbx.js';
export { Ktx2, useKTX2 } from '../core/Ktx2.js';
export { Progress, useProgress } from '../core/Progress.js';
export { IsObject, Texture, useTexture } from '../core/Texture.js';
export { VideoTexture, useVideoTexture } from '../core/VideoTexture.js';
export { useFont } from '../core/useFont.js';
export { checkIfFrameIsEmpty, getFirstFrame, useSpriteLoader } from '../core/useSpriteLoader.js';
export { Helper, useHelper } from '../core/Helper.js';
export { Stats } from '../core/Stats.js';
export { StatsGl } from '../core/StatsGl.js';
export { useDepthBuffer } from '../core/useDepthBuffer.js';
export { useAspect } from '../core/useAspect.js';
export { useCamera } from '../core/useCamera.js';
export { DetectGPU, useDetectGPU } from '../core/DetectGPU.js';
export { Bvh, useBVH } from '../core/Bvh.js';
export { useContextBridge } from '../core/useContextBridge.js';
export { useAnimations } from '../core/useAnimations.js';
export { Fbo, useFBO } from '../core/Fbo.js';
export { useIntersect } from '../core/useIntersect.js';
export { useBoxProjectedEnv } from '../core/useBoxProjectedEnv.js';
export { BBAnchor } from '../core/BBAnchor.js';
export { TrailTexture, useTrailTexture } from '../core/TrailTexture.js';
export { Example } from '../core/Example.js';
export { SpriteAnimator, useSpriteAnimator } from '../core/SpriteAnimator.js';
export { CurveModifier } from '../core/CurveModifier.js';
export { MeshDistortMaterial } from '../core/MeshDistortMaterial.js';
export { MeshWobbleMaterial } from '../core/MeshWobbleMaterial.js';
export { MeshReflectorMaterial } from '../core/MeshReflectorMaterial.js';
export { MeshRefractionMaterial } from '../core/MeshRefractionMaterial.js';
export { MeshTransmissionMaterial } from '../core/MeshTransmissionMaterial.js';
export { MeshDiscardMaterial } from '../core/MeshDiscardMaterial.js';
export { MultiMaterial } from '../core/MultiMaterial.js';
export { PointMaterial, PointMaterialImpl } from '../core/PointMaterial.js';
export { shaderMaterial } from '../core/shaderMaterial.js';
export { SoftShadows } from '../core/softShadows.js';
export { Box, Capsule, Circle, Cone, Cylinder, Dodecahedron, Extrude, Icosahedron, Lathe, Octahedron, Plane, Polyhedron, Ring, Shape, Sphere, Tetrahedron, Torus, TorusKnot, Tube } from '../core/shapes.js';
export { RoundedBox, RoundedBoxGeometry } from '../core/RoundedBox.js';
export { ScreenQuad } from '../core/ScreenQuad.js';
export { Center } from '../core/Center.js';
export { Resize } from '../core/Resize.js';
export { Bounds, useBounds } from '../core/Bounds.js';
export { CameraShake } from '../core/CameraShake.js';
export { Float } from '../core/Float.js';
export { Stage } from '../core/Stage.js';
export { Backdrop } from '../core/Backdrop.js';
export { Shadow } from '../core/Shadow.js';
export { Caustics } from '../core/Caustics.js';
export { ContactShadows } from '../core/ContactShadows.js';
export { AccumulativeShadows, RandomizedLight, accumulativeContext } from '../core/AccumulativeShadows.js';
export { SpotLight, SpotLightShadow } from '../core/SpotLight.js';
export { Environment, EnvironmentCube, EnvironmentMap, EnvironmentPortal } from '../core/Environment.js';
export { Lightformer } from '../core/Lightformer.js';
export { Sky, calcPosFromAngles } from '../core/Sky.js';
export { Stars } from '../core/Stars.js';
export { Cloud, CloudInstance, Clouds } from '../core/Cloud.js';
export { Sparkles } from '../core/Sparkles.js';
export { useEnvironment } from '../core/useEnvironment.js';
export { MatcapTexture, useMatcapTexture } from '../core/MatcapTexture.js';
export { NormalTexture, useNormalTexture } from '../core/NormalTexture.js';
export { Wireframe } from '../core/Wireframe.js';
export { ShadowAlpha } from '../core/ShadowAlpha.js';
export { Point, Points, PointsBuffer, PositionPoint } from '../core/Points.js';
export { Instance, InstancedAttribute, Instances, Merged, PositionMesh, createInstances } from '../core/Instances.js';
export { Segment, SegmentObject, Segments } from '../core/Segments.js';
export { Detailed } from '../core/Detailed.js';
export { Preload } from '../core/Preload.js';
export { BakeShadows } from '../core/BakeShadows.js';
export { meshBounds } from '../core/meshBounds.js';
export { AdaptiveDpr } from '../core/AdaptiveDpr.js';
export { AdaptiveEvents } from '../core/AdaptiveEvents.js';
export { PerformanceMonitor, usePerformanceMonitor } from '../core/PerformanceMonitor.js';
export { RenderTexture } from '../core/RenderTexture.js';
export { RenderCubeTexture } from '../core/RenderCubeTexture.js';
export { Mask, useMask } from '../core/Mask.js';
export { Hud } from '../core/Hud.js';
export { Fisheye } from '../core/Fisheye.js';
export { MeshPortalMaterial } from '../core/MeshPortalMaterial.js';
export { calculateScaleFactor } from '../core/calculateScaleFactor.js';
import '@babel/runtime/helpers/esm/extends';
import 'react';
import 'three';
import '@react-three/fiber';
import 'three-stdlib';
import 'troika-three-text';
import 'suspend-react';
import '../helpers/constants.js';
import 'meshline';
import 'maath';
import 'zustand';
import 'hls.js';
import 'stats.js';
import '../helpers/useEffectfulState.js';
import 'stats-gl';
import 'detect-gpu';
import 'three-mesh-bvh';
import '../helpers/deprecated.js';
import '../materials/BlurPass.js';
import '../materials/ConvolutionMaterial.js';
import '../materials/MeshReflectorMaterial.js';
import '../materials/MeshRefractionMaterial.js';
import '../materials/DiscardMaterial.js';
import '@monogrid/gainmap-js';
import '../helpers/environment-assets.js';
import '../materials/SpotLightMaterial.js';
import '../materials/WireframeMaterial.js';
